<?php
/**
 * UfitPay Virtual Account Payment  Gateway Module
 *
 * UfitPay Payment Gateway modules allow you to integrate UfitPay Virtual Account  payment solutions with the
 * WHMCS platform.
 *
 * For more information, please visit https://bank.ufitpay.com.
 *
 * @copyright Copyright (c) UfitPay So0lutions Limited 2022
 */

if (!defined("WHMCS")) {
    die("This file cannot be accessed directly");
}

function ufitpay_MetaData(){
    return array(
        'DisplayName' => 'UfitPay Virtual Account Payment Gateway Module',
        'APIVersion' => '1.1', 
        'DisableLocalCreditCardInput' => true,
        'TokenisedStorage' => false,
    );
}

function ufitpay_config(){
    return array(
        'FriendlyName' => array(
            'Type' => 'System',
            'Value' => 'UfitPay Virtual Account Payment Gateway',
        ),
        'apiKey' => array(
            'FriendlyName' => 'Merchant API Key',
            'Type' => 'text',
            'Size' => '45',
            'Default' => '',
            'Description' => 'Enter your UfitPay merchant API key here',
        ),
        'apiToken' => array(
            'FriendlyName' => 'Secret Key',
            'Type' => 'password',
            'Size' => '45',
            'Default' => '',
            'Description' => 'Enter your UfitPay merchant API token here',
        ),
        'paymentWindow' => array(
            'FriendlyName' => 'Payment Window',
            'Type' => 'dropdown',
            'Options' => array(
                '30' => '30 Minutes',
                '60' => '1 Hour',
                '90' => '1 Hour, 30 Minutes',
				'120' => '2 Hours',
				'180' => '3 Hours',
            ),
            'Description' => 'Choose how long you want to give customers to complete payment before payment is timed-out',
        ),
    );
}

function ufitpay_link($params){
    // Gateway Configuration Parameters
    $apiToken = $params['apiToken'];
    $apiKey = $params['apiKey'];
    $paymentWindow = $params['paymentWindow'];

    // Invoice Parameters
    $invoiceId = $params['invoiceid'];
    $description = $params["description"];
    $amount = $params['amount'];
    $currencyCode = $params['currency'];

    // Client Parameters
    $firstname = $params['clientdetails']['firstname'];
    $lastname = $params['clientdetails']['lastname'];
    $email = $params['clientdetails']['email'];
    $phone = $params['clientdetails']['phonenumber'];

    // System Parameters
    $companyName = $params['companyname'];
    $systemUrl = $params['systemurl'];
    $returnUrl = $params['returnurl'];
    $langPayNow = $params['langpaynow'];
    $moduleDisplayName = $params['name'];
    $moduleName = $params['paymentmethod'];
    $whmcsVersion = $params['whmcsVersion'];
	
	$autoStart = ( !array_key_exists('id', $_GET) );
	
	if (strtoupper($currencyCode) != 'NGN') {
        return ("<b style='color:red;margin:2px;padding:2px;border:1px dotted;display: block;border-radius: 10px;font-size: 13px;'>Sorry UfitPay Virtual Account Payment currently support only NGN payments. <i>$currency</i> is not yet supported.</b>");
    }
   
    $callbackURL = $systemUrl . '/modules/gateways/callback/' . $moduleName . '.php?invoiceId='.$invoiceId;

    $htmlOutput = '<div>';
    $htmlOutput .= '<button class="btn btn-lg btn-success" type="button" id="inv_pay_b" value="' . $langPayNow . '"><i class="fa fa-bank fa-fw"></i> ' . $langPayNow . '</button>';
    $htmlOutput .= '</div>';
	$htmlOutput .= '<script src="https://embed.ufitpay.com/'.$apiKey.'"></script>';
	$htmlOutput .= '<script type="text/javascript">
							(typeof $ === "undefined") && document.write(\'<scr\'+\'ipt type="text/javascript" src="https://code.jquery.com/jquery-1.12.3.min.js"></scri\'+\'pt>\');
					</script>';
	$htmlOutput .= '<script type="text/javascript">
				function validateUfitPayPayment(data) {
					var reference = data.reference
					if(data.event=="completed") {
						var mess = "Payment successfully completed. Transaction reference is "+reference;
							alert(mess);
							location.reload();
					}
				}
				function pay(){
					initializePayWithUfitPay({
						resource: "disposableaccount",
						payer_name: "'.strtoupper($companyName.'-'.$firstname.' '.$lastname).'", 
						payer_email: "'.$email.'",
						amount: "'.$amount.'",
						reference: "INVOICE-'.$invoiceId."-".time().'",
						validity: "'.$paymentWindow.'",
						callback_url: "'.$callbackURL.'",
						callback_function: "validateUfitPayPayment"
					});
				}
				document.getElementById("inv_pay_b").onclick = function() { pay();}
			' . ( $autoStart ? '$(document).ready(function() { setTimeout(pay, 4200); });' : '' ) . '	
			</script>';

    return $htmlOutput;
}